Gentelella Alela! |

Welcome,

## John Doe

### Form advanced

## Input Mask

Date Mask
Phone mask
Custom Mask
Serial Number
TaxID Mask
Credit Card Mask

## Color Picker

Default Input
Styled
Horizontal bar
Vertical bar
Inline picker

## Input knob

Display value

× 'cursor' mode

Step 0.1

Angle arc

Alternate design

Angle offset

## Date Pickers Available with multiple designs

December 30, 2014 - January 28, 2015

Date Range Picker with opening to right and left

December 30, 2014 - January 28, 2015
Date Range Picker
Date and Time
(success)
(success)
(success)
(success)

## Date Pickers Available with multiple designs

Basic Example
Only Date Picker
Only Time Picker For 24H format use format: 'HH:mm'
Using ReadOnly
Linked Picker Parent
Linked Picker Children

## Grid Slider

Default grid slider with min and max values

Grid with slider labels are far away outside it's container

Grid with labels inside container using force_edges attribute

Create Grid with pre-defined steps

Prevent one from dragging the labels

Grid with minimum and maximum values

Grid With time in 24 hour format

X px
Y px
Width px
Height px
Rotate deg
ScaleX
ScaleY

#### Cropped

16:9 4:3 1:1 2:3 Free
VM0 VM1 VM2 VM3
Cropper.js